function [t,y]=runge_kutta(t_0,y_0,t_end,h,f);
% [t,y]=runge_kutta(t_0,y_0,t_end,h,f);
%
% Klassisches Runge Kutta Verfahren
% Programm loest die AWA
%    y'=f(t,y)   y(t_0)=y_0
% auf dem Intervall [t_0,t_end] mittels Runge Kutta zur Schrittweite h.
%
% input: 
%   t_0:    t-Startwert
%   y_0:    y-Startwert
%   t_end:  Intervallende
%   h:      Schrittweite
%   f:      function handle fuer die DGL-Function
%           von der Form f(t,y)
% output:
%   t:      Vektor aller verwendeten t_i=t_0+(i-1)*h
%   y:      Vektor der alle Approximationen y_i an die Loesung y(t_i)

t=t_0:h:t_end;
n=length(t);
y=zeros(length(y_0),n);
y(:,1)=y_0;
for i=2:n
    k1=f(t(i-1),y(:,i-1));
    k2=f(t(i-1)+0.5*h,y(:,i-1)+0.5*h*k1);
    k3=f(t(i-1)+0.5*h,y(:,i-1)+0.5*h*k2);
    k4=f(t(i-1)+h,y(:,i-1)+h*k3);
    y(:,i)=y(:,i-1)+h/6*(k1+2*k2+2*k3+k4);
end
